#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#ifndef _MAIN_H_
#define _MAIN_H_

#include "difftable.h"

enum {
  S2 = 0, S4, S6, S8, S10, S12,
  S14, S16, S18, S20, S22, S24,
  NUMSHADOWS, NUMDIFS
};

typedef struct Data {

  // SIMULATION PARAMETERS
  double dt;         // timestep
  int natoms;        // number of atoms in the system
  int n, nsteps;     // n is the current iteration, nsteps the total number
  double pe, energy; // pe is potential energy, energy is total energy

  // PER ATOMS PARAMETERS
  double *pos;       // atom positions
  double *midstep;   // midstep positions
  double *vel;       // atom velocities
  double *f;         // forces on each atom
  double *mass;      // atom masses

  // SHADOW HAMILTONIAN PARAMETERS
  DifTab *diftab;    // structure for backward differences
  double *sham;      // sham stores interpolated shadow hamiltonians
  double *trunc;     // trunc stores truncated shadow hamiltonians

  // SHADOW HAMILTONIAN FORUMULA COEFFICIENTS
  double **coef;     // coefficients for shadow hamiltonian formulas
                     // (formulas using backward differences)

  // OUTPUT FILE PARAMETERS - 3 files are created by this program
  FILE *sim_out; // energy, position, & velocity: <filename>.sim
  FILE *in_out;  // interpolated shadow Hamiltonians: <filename>.interp
  FILE *tr_out;  // truncated shadow Hamiltonians: <filename>.trunc
  
} Data;

int initialize(int argc, char **argv, Data *data);
int initial_conditions(Data *data);

#endif // _MAIN_H_
